@@ -1,6 +1,6 @@
-#!/bin/sh
+#!/bin/bash
 
-# Copyright 2015-2023 Dimitris Zlatanidis Orestiada, Greece
+# Copyright 2015-2025 Dimitris Zlatanidis Orestiada, Greece
 # All rights reserved.
 #
 # Redistribution and use of this script, with or without modification, is
@@ -21,14 +21,8 @@
 #  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
-grab_version() {
-# Grab version from __metadata__.py file
-cat sun/__metadata__.py | grep "__version_info__: tuple = (" \
-    | tr -d "[:space:]" | cut -c25-29 | tr , .
-}
-
 PRGNAM=sun
-VERSION=${VERSION:-$(grab_version)}
+VERSION=$(cat pyproject.toml | grep "version =" | grep -oe "\([0-9.]*\)")
 TAG=${TAG:-_dsw}
 
 ARCHIVES="$PRGNAM-$VERSION.tar.gz $PRGNAM-$VERSION.zip \
@@ -42,7 +36,7 @@ for file in $ARCHIVES; do
         ./$PRGNAM.SlackBuild
         rm $file
     fi
-done 
+done
 
 # install or upgrade with new version as Slackware package
 upgradepkg --install-new /tmp/$PRGNAM-$VERSION-*$TAG.t?z
